@@ -65,6 +65,28 @@ def timer(logger):
         return wrapper
     return d_timer
 
+def azureml_timer(logger, run):
+    def d_timer(func):
+        """time the running time of the passed in function"""
+        @wraps(func)
+        def wrapper(*args, **kwargs):
+            t1 = time.time()
+            result = func(*args, **kwargs)
+            t2 = time.time() - t1
+            custom_dimensions = {
+                                "parent_run_id": run.parent.id,
+                                "step_id": run.id,
+                                "step_name": run.name,
+                                "experiment_name": run.experiment.name,
+                                "run_url": run.parent.get_portal_url(),
+                                "duration_in_sec": t2,
+                                "method_name":func.__name__
+                                }
+            logger.info('{} ran in: {} sec'.format(func.__name__, t2), custom_dimensions)
+            return result
+        
+        return wrapper
+
 class JoblibUtilities:
     @staticmethod
     def load_file_from_txt(file_content):
@@ -1047,6 +1069,9 @@ class ConfigProvider:
         #self.SUBSCRIPTION_ENTERPRISE = data["Azure"]["Subscriptions"]["Enterprise"]
         #self.SUBSCRIPTION_PROFESSIONAL = data["Azure"]["Subscriptions"]["Professional"]
 
+        #ApplicationInsights
+        self.APPLICATION_INSIGHTS_CONNECTION_STRING = data["Azure"]["ApplicationInsights"]["ConnectionString"]
+
 class ConfigGenerator:
     def __init__(self, config_template_file):
         """initializing class with path to the template of config file
